@@ -4,8 +4,10 @@ from pymodelextractor.tests.learners_tests.test_lstar_learner import TestLStarLe
 from pymodelextractor.tests.learners_tests.test_bounded_lstar_learner import TestBoundedLStarLearner
 from pymodelextractor.tests.learners_tests.test_lstarcol_learner import TestLStarColLearner
 from pymodelextractor.tests.learners_tests.test_kearns_vazirani_learner import TestKearnsVaziraniLearner
-from pymodelextractor.tests.learners_tests.test_pdfa_lstar_learner import TestPDFALStarLearner
 from pymodelextractor.tests.learners_tests.test_pdfa_lstarcol_learner import TestPDFALStarColLearner
+from pymodelextractor.tests.learners_tests.test_pdfa_lstar_quant_learner import TestPDFALStarQuantLearner
+from pymodelextractor.tests.learners_tests.test_pdfa_lstar_tolerance_learner import TestPDFALStarToleranceLearner
+from pymodelextractor.tests.learners_tests.test_pdfa_lstarcol_quant_learner import TestPDFALStarColQuantLearner
 from tests.learners_tests.test_lambda_star_learner import TestLambdaStarLearnerWithEqualityAlgebra
 from tests.learners_tests.test_pdfa_teachers_pdfa_lstar import TestPDFATeachersLStar
 from tests.learners_tests.test_pdfa_teachers_pdfa_lstar_col import TestPDFATeachersLStarCol
@@ -24,10 +26,12 @@ from tests.learners_tests.test_pdfa_quantization_n_ary_tree_learner_running_exam
 def run():
     test_classes_to_run = [TestLStarLearner,
                            TestLStarColLearner,
-                           TestPDFALStarLearner,
+                           TestPDFALStarQuantLearner,
+                           TestPDFALStarToleranceLearner,
+                           TestPDFALStarColQuantLearner,
+                           TestPDFALStarColLearner,
                            TestKearnsVaziraniLearner,
                            TestLStarLearner,
-                           TestPDFALStarColLearner,
                            TestPDFATeachersLStar,
                            TestPDFATeachersLStarCol,
                            TestPACBooleanModelTeachers, 
