@@ -21,16 +21,16 @@ class TestPDFATeachersLStar(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator())
         teacher2 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(), sample_size=500, 
                                               max_seq_length=20)                    
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator=WFAToleranceComparator(), max_seq_length=20)
+        teacher3 = PACProbabilisticTeacher(model, epsilon = 0.05, delta = 0.01, comparator=WFAToleranceComparator(), max_seq_length=20)
         teacher4 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(), full_prefix_set=True, 
                                               max_seq_length=10)
         teacher5 = SampleBatchProbabilisticTeacher(model, comparator=WFAToleranceComparator(), full_prefix_set=True, 
                                               max_seq_length=10)
-        result1 = self.learner.learn(teacher1, tolerance=0, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=0, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=0, verbose=True)
-        result4 = self.learner.learn(teacher4, tolerance=0, verbose=True)  
-        result5 = self.learner.learn(teacher5, tolerance=0, verbose=True)   
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)
+        result4 = self.learner.learn(teacher4, verbose=True)  
+        result5 = self.learner.learn(teacher5, verbose=True)   
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model        
@@ -48,16 +48,16 @@ class TestPDFATeachersLStar(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator())
         teacher2 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(), sample_size=500, 
                                               max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator=WFAToleranceComparator(), max_seq_length=20)
+        teacher3 = PACProbabilisticTeacher(model, epsilon = 0.05, delta = 0.01, comparator=WFAToleranceComparator(), max_seq_length=20)
         teacher4 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(), full_prefix_set=True, 
                                               max_seq_length=10)
         teacher5 = SampleBatchProbabilisticTeacher(model, comparator=WFAToleranceComparator(), full_prefix_set=True, 
                                               max_seq_length=10)                                      
-        result1 = self.learner.learn(teacher1, tolerance=0, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=0, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=0, verbose=True)        
-        result4 = self.learner.learn(teacher4, tolerance=0, verbose=True)                
-        result5 = self.learner.learn(teacher5, tolerance=0, verbose=True)   
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)        
+        result4 = self.learner.learn(teacher4, verbose=True)                
+        result5 = self.learner.learn(teacher5, verbose=True)   
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -77,17 +77,17 @@ class TestPDFATeachersLStar(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))
         teacher2 = SampleProbabilisticTeacher(model, comparator = WFAToleranceComparator(tolerance), sample_size=500,
                                               max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance),
+        teacher3 = PACProbabilisticTeacher(model, epsilon = 0.05, delta = 0.01, comparator = WFAToleranceComparator(tolerance),
                                            max_seq_length=20)
         teacher4 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), full_prefix_set=True, 
                                               max_seq_length=10)
         teacher5 = SampleBatchProbabilisticTeacher(model, comparator=WFAToleranceComparator(), full_prefix_set=True, 
                                               max_seq_length=10)
-        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
-        result4 = self.learner.learn(teacher4, tolerance=tolerance, verbose=True)
-        result5 = self.learner.learn(teacher5, tolerance=tolerance, verbose=True)
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)
+        result4 = self.learner.learn(teacher4, verbose=True)
+        result5 = self.learner.learn(teacher5, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -106,17 +106,17 @@ class TestPDFATeachersLStar(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))        
         teacher2 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), sample_size=500,
                                               max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator=WFAToleranceComparator(tolerance),
+        teacher3 = PACProbabilisticTeacher(model, epsilon = 0.05, delta = 0.01, comparator=WFAToleranceComparator(tolerance),
                                            max_seq_length=20)
         teacher4 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), full_prefix_set=True, 
                                               max_seq_length=10)
         teacher5 = SampleBatchProbabilisticTeacher(model, comparator=WFAToleranceComparator(), full_prefix_set=True, 
                                               max_seq_length=10)
-        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
-        result4 = self.learner.learn(teacher4, tolerance=tolerance, verbose=True)
-        result5 = self.learner.learn(teacher5, tolerance=tolerance, verbose=True)
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)
+        result4 = self.learner.learn(teacher4, verbose=True)
+        result5 = self.learner.learn(teacher5, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -136,17 +136,17 @@ class TestPDFATeachersLStar(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))        
         teacher2 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), sample_size=500,
                                               max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator=WFAToleranceComparator(tolerance),
+        teacher3 = PACProbabilisticTeacher(model, epsilon = 0.05, delta = 0.01, comparator=WFAToleranceComparator(tolerance),
                                            max_seq_length=20)
         teacher4 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), full_prefix_set=True, 
                                               max_seq_length=10)
         teacher5 = SampleBatchProbabilisticTeacher(model, comparator=WFAToleranceComparator(), full_prefix_set=True, 
                                               max_seq_length=10)
-        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
-        result4 = self.learner.learn(teacher4, tolerance=tolerance, verbose=True)
-        result5 = self.learner.learn(teacher5, tolerance=tolerance, verbose=True)
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)
+        result4 = self.learner.learn(teacher4, verbose=True)
+        result5 = self.learner.learn(teacher5, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -164,17 +164,17 @@ class TestPDFATeachersLStar(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))        
         teacher2 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), sample_size=500,
                                               max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance),
+        teacher3 = PACProbabilisticTeacher(model, epsilon = 0.05, delta = 0.01, comparator = WFAToleranceComparator(tolerance),
                                            max_seq_length=20)
         teacher4 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), full_prefix_set=True, 
                                               max_seq_length=10)
         teacher5 = SampleBatchProbabilisticTeacher(model, comparator=WFAToleranceComparator(), full_prefix_set=True, 
                                               max_seq_length=10)
-        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
-        result4 = self.learner.learn(teacher4, tolerance=tolerance, verbose=True)
-        result5 = self.learner.learn(teacher5, tolerance=tolerance, verbose=True)
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)
+        result4 = self.learner.learn(teacher4, verbose=True)
+        result5 = self.learner.learn(teacher5, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
@@ -193,17 +193,17 @@ class TestPDFATeachersLStar(unittest.TestCase):
         teacher1 = PDFATeacher(model, WFAToleranceComparator(tolerance))        
         teacher2 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), sample_size=500,
                                               max_seq_length=20)
-        teacher3 = PACProbabilisticTeacher(model, 0.05, 0.01, comparator = WFAToleranceComparator(tolerance),
+        teacher3 = PACProbabilisticTeacher(model, epsilon = 0.05, delta = 0.01, comparator = WFAToleranceComparator(tolerance),
                                            max_seq_length=20)
         teacher4 = SampleProbabilisticTeacher(model, comparator=WFAToleranceComparator(tolerance), full_prefix_set=True, 
                                               max_seq_length=10)
         teacher5 = SampleBatchProbabilisticTeacher(model, comparator=WFAToleranceComparator(), full_prefix_set=True, 
                                               max_seq_length=10)
-        result1 = self.learner.learn(teacher1, tolerance=tolerance, verbose=True)
-        result2 = self.learner.learn(teacher2, tolerance=tolerance, verbose=True)
-        result3 = self.learner.learn(teacher3, tolerance=tolerance, verbose=True)
-        result4 = self.learner.learn(teacher4, tolerance=tolerance, verbose=True)
-        result5 = self.learner.learn(teacher5, tolerance=tolerance, verbose=True)
+        result1 = self.learner.learn(teacher1, verbose=True)
+        result2 = self.learner.learn(teacher2, verbose=True)
+        result3 = self.learner.learn(teacher3, verbose=True)
+        result4 = self.learner.learn(teacher4, verbose=True)
+        result5 = self.learner.learn(teacher5, verbose=True)
         extracted_model1 = result1.model
         extracted_model2 = result2.model
         extracted_model3 = result3.model
